import tkinter as tk
import os  
from app1 import Homepage
from feeding_dashboard import UploadPage

class MainApplication(tk.Tk):
    def __init__(self):
        super().__init__()
        print("MainApplication initialized.")  
        self.title("Patient Referral System")
        self.geometry("1200x800")

        self.container = tk.Frame(self)
        self.container.pack(fill="both", expand=True)
        self.container.grid_rowconfigure(0, weight=1)
        self.container.grid_columnconfigure(0, weight=1)

        self.frames = {}

        for F in (Homepage, UploadPage):
            page_name = F.__name__
            print(f"Creating {page_name} frame.")  
            frame = F(parent=self.container, controller=self)
            self.frames[page_name] = frame
            frame.grid(row=0, column=0, sticky="nsew")
            print(f"{page_name} frame created and added to frames dictionary.")  # Debug

        print("Showing Homepage frame.")  
        self.show_frame("Homepage")
        self.protocol("WM_DELETE_WINDOW", self.on_closing)

    def show_frame(self, page_name):
        print(f"Attempting to show {page_name} frame.")  # Debug
        frame = self.frames.get(page_name)
        if frame:
            print(f"Raising {page_name} frame.")  # Debug
            frame.tkraise()
            if page_name == "Homepage":
                print("Calling show_homepage on Homepage frame.")  # Debug
                frame.show_homepage()
        else:
            print(f"Frame {page_name} not found in frames dictionary.")  # Debug
            
    def on_closing(self):
        """Delete data.csv when the application is closed."""
        if os.path.exists("data.csv"):
            os.remove("data.csv")
        self.destroy()

if __name__ == "__main__":
    app = MainApplication()
    app.mainloop()
