import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.impute import SimpleImputer
from sklearn.preprocessing import StandardScaler
from sklearn.preprocessing import MinMaxScaler



file_path = "FeedingDashboardData.csv"
df = pd.read_csv(file_path)


REQUIRED_COLUMNS = [
    "end_tidal_co2", "feed_vol", "feed_vol_adm", "fio2", "fio2_ratio", 
    "insp_time", "oxygen_flow_rate", "peep", "pip", "resp_rate", "sip", 
    "tidal_vol", "tidal_vol_actual", "tidal_vol_kg", "tidal_vol_spon", "bmi", "referral"
]


missing_columns = [col for col in REQUIRED_COLUMNS if col not in df.columns]
if missing_columns:
    print(f"⚠️ Missing columns in the uploaded data: {missing_columns}")
    raise ValueError("Uploaded data is missing required columns.")


imputer = SimpleImputer(strategy="median")
df[REQUIRED_COLUMNS[:-1]] = imputer.fit_transform(df[REQUIRED_COLUMNS[:-1]])

# feetuee scaling
scaler = MinMaxScaler()
df[REQUIRED_COLUMNS[:-1]] = scaler.fit_transform(df[REQUIRED_COLUMNS[:-1]])


train_data, ml_data = train_test_split(df, test_size=0.2, random_state=42)  #Split DAta


train_data.to_csv("dashboard_data1.csv", index=False)
ml_data.to_csv("ml_data1.csv", index=False)

print("✅ Data successfully validated, prepared, and saved!")
