import unittest
import numpy as np
import joblib
import os

class TestDietitianModel(unittest.TestCase):
    def setUp(self):
        # Load the model once for all tests
        model_path = "dietitian_model.pkl"
        self.assertTrue(os.path.exists(model_path), "Model file not found.")
        self.model = joblib.load(model_path)

        # Example input (16 features in the correct order)
        self.valid_input = np.array([[
            35,     # end_tidal_co2
            250,    # feed_vol
            245,    # feed_vol_adm
            0.4,    # fio2
            300,    # fio2_ratio
            1.2,    # insp_time
            5,      # oxygen_flow_rate
            6,      # peep
            18,     # pip
            22,     # resp_rate
            5,      # sip
            450,    # tidal_vol
            460,    # tidal_vol_actual
            7.5,    # tidal_vol_kg
            100,    # tidal_vol_spon
            23.5    # bmi
        ]])

    def test_model_predict_shape(self):
        # Ensure the output has correct shape
        prediction = self.model.predict(self.valid_input)
        self.assertEqual(prediction.shape, (1,), "Prediction should return a single value.")

    def test_prediction_output_type(self):
        # Ensure the prediction is a binary classification (0 or 1)
        prediction = self.model.predict(self.valid_input)[0]
        self.assertIn(prediction, [0, 1], "Prediction should be 0 or 1 (No Referral or Need Referral).")

    def test_model_input_size(self):
        # Ensure the model expects 16 features
        expected_features = 16
        self.assertEqual(self.valid_input.shape[1], expected_features, "Input should have 16 features.")

if __name__ == "__main__":
    unittest.main()
