import pandas as pd
import joblib
import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import classification_report, accuracy_score


df = pd.read_csv("ml_data1.csv")

features = [
    "end_tidal_co2", "feed_vol", "feed_vol_adm", "fio2", "fio2_ratio",
    "insp_time", "oxygen_flow_rate", "peep", "pip", "resp_rate", "sip",
    "tidal_vol", "tidal_vol_actual", "tidal_vol_kg", "tidal_vol_spon", "bmi"
]

df = df.dropna()

X = df[features]
y = df["referral"]

X.columns = features

X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.8, random_state=42)

model = RandomForestClassifier(n_estimators=100, random_state=42)
model.fit(X_train, y_train)

joblib.dump(model, "dietitian_model.pkl")

print("✅ Model trained and saved successfully using only 20% of the data!")

y_pred = model.predict(X_test)
print("📈 Accuracy:", accuracy_score(y_test, y_pred))
print("📊 Classification Report:\n", classification_report(y_test, y_pred))

